@@ -4,8 +4,8 @@
 
 ;; Author: Takashi Masuda <masutaka.net@gmail.com>
 ;; URL: https://github.com/masutaka/emacs-helm-raindrop
-;; Package-Version: 0.2.0
-;; Package-Revision: 0.2.0-0-g0c87eddc7f15
+;; Package-Version: 20250806.1220
+;; Package-Revision: 6c080b1acf51
 ;; Package-Requires: ((emacs "29.1") (helm "4.0.4") (request "0.3.2"))
 
 ;; This program is free software: you can redistribute it and/or modify
@@ -276,10 +276,8 @@ Extract title and show it before the remaining S-expression."
 
 ;;; Process handler
 
-;;;###autoload
 (defun helm-raindrop-http-request ()
   "Fetch all items from configured collections and cache them."
-  (interactive)
   (helm-raindrop-debug-session-start)
   (when (get-buffer helm-raindrop--work-buffer-name)
     (kill-buffer helm-raindrop--work-buffer-name))
